@@ -1,5 +1,4 @@
 use crate::{parser::PError, *};
-use alloc::string::ToString;
 
 fn show_err<E>(e: PError) -> E {
     panic!("{}", e)
@@ -36,9 +35,11 @@ fn test_yaml() {
                 "b1" => 4.,
                 "b2" => node!([
                     "50%",
-                    node!(Yaml::Float("2e-4".to_string())),
-                    node!(Yaml::Float("NaN".to_string())),
-                    node!(Yaml::Float("-inf".to_string())),
+                    8,
+                    16,
+                    2e-4,
+                    f64::NAN,
+                    -f64::INFINITY,
                     "-.infs",
                     "2001-11-23 15:01:42 -5",
                 ]),
@@ -68,6 +69,7 @@ fn test_yaml() {
             ]),
         })
     );
+    assert_eq!(node.tag(), "tag:test.x.prefix:root");
     let k = node!("a0 bb");
     assert_eq!(node[k].tag(), "tag:test.x.prefix:foo");
     let k = node!("-a2");
@@ -90,7 +92,7 @@ fn test_dump() {
         }),
         node!(["a", "b"]),
     ];
-    let doc = dump(&nodes, &Default::default());
+    let doc = dump(&nodes, &[]);
     assert_eq!(doc.replace("\r\n", "\n"), DOC.replace("\r\n", "\n"));
 }
 
@@ -114,6 +116,7 @@ fn test_indent() {
             "map" => node!(["a", "b", "c"]),
         })
     );
+    assert_eq!(node2.tag(), "normal-sequence");
     assert_eq!(node2, node!(["a1", "true of", "a2"]));
 }
 
